Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5441)

Unified Diff: chrome/common/pref_names.cc

Issue 10832035: Switch from SignedSettings to DeviceSettingsService. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: once more? Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/pref_names.cc
diff --git a/chrome/common/pref_names.cc b/chrome/common/pref_names.cc
index 04138b1d2562b87f31d6aec902b1525ba11c4f0b..612262dff3d87c9221987687c62b2d6e68c0f244 100644
--- a/chrome/common/pref_names.cc
+++ b/chrome/common/pref_names.cc
@@ -1766,9 +1766,9 @@ const char kGSSAPILibraryName[] = "auth.gssapi_library_name";
const char kAllowCrossOriginAuthPrompt[] = "auth.allow_cross_origin_prompt";
#if defined(OS_CHROMEOS)
// Dictionary for transient storage of settings that should go into signed
// settings storage before owner has been assigned.
-const char kSignedSettingsCache[] = "signed_settings_cache";
+const char kDeviceSettingsCache[] = "signed_settings_cache";
// The hardware keyboard layout of the device. This should look like
// "xkb:us::eng".
@@ -1766,9 +1766,9 @@ const char kGSSAPILibraryName[] = "auth.gssapi_library_name";
const char kAllowCrossOriginAuthPrompt[] = "auth.allow_cross_origin_prompt";
#if defined(OS_CHROMEOS)
-// Dictionary for transient storage of settings that should go into signed
+// Dictionary for transient storage of settings that should go into device
// settings storage before owner has been assigned.

Powered by Google App Engine
This is Rietveld 408576698